@@ -7,8 +7,7 @@ use utf8;
 use warnings;
 
 use List::Util qw(min max);
-use Text::CharWidth qw(mbswidth);
-use Text::WideChar::Util 0.04 qw(mbtrunc);
+use Text::WideChar::Util 0.07 qw(mbswidth mbtrunc);
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -33,7 +32,7 @@ our @EXPORT_OK = qw(
                        ta_wrap
                );
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 # used to find/strip escape codes from string
 our $re       = qr/
@@ -700,8 +699,8 @@ sub ta_add_color_resets {
 1;
 # ABSTRACT: Routines for text containing ANSI escape codes
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -710,7 +709,7 @@ Text::ANSI::Util - Routines for text containing ANSI escape codes
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -765,7 +764,7 @@ version 0.10
  say ta_mbtrunc(...);
 
  # highlight the first occurence of some string within text
- say ta_highlight("some text", "ome", "\x[7m\x[31m");
+ say ta_highlight("some text", "ome", "\e[7m\e[31m");
 
  # ditto, but highlight all occurrences
  say ta_highlight_all(...);
@@ -910,18 +909,18 @@ information like C<max_word_width>, C<min_word_width>.
 
 =back
 
-Performance: ~750/s on my Core i5-2400 3.1GHz desktop for a ~1KB of text (with
-zero to moderate amount of color codes). As a comparison, Text::WideChar::Util's
-wrap() can do about 3100/s.
+Performance: ~500/s on my Core i5 1.7GHz laptop for a ~1KB of text (with zero to
+moderate amount of color codes). As a comparison, Text::WideChar::Util's wrap()
+can do about 2000/s.
 
 =head2 ta_mbwrap($text, $width, \%opts) => STR
 
 Like ta_wrap(), but it uses ta_mbswidth() instead of ta_length(), so it can
 handle wide characters.
 
-Performance: ~650/s on my Core i5-2400 3.1GHz desktop for a ~1KB of text (with
-zero to moderate amount of color codes). As a comparison, Text::WideChar::Util's
-mbwrap() can do about 2300/s.
+Performance: ~300/s on my Core i5 1.7GHz laptop for a ~1KB of text (with zero to
+moderate amount of color codes). As a comparison, Text::WideChar::Util's
+mbwrap() can do about 650/s.
 
 =head2 ta_add_color_resets(@text) => LIST
 
@@ -997,9 +996,6 @@ care not to mess up existing colors.
 
 C<$needle> can be a string or a Regexp object.
 
-Performance: ~ 20k/s on my Core i5-2400 3.1GHz desktop for a ~ 1KB of text and a
-needle of length ~ 7.
-
 Implementation note: to not mess up colors, we save up all color codes from the
 last reset (C<\e[0m>) before inserting the highlight color + highlight text.
 Then we issue C<\e[0m> and the saved up color code to return back to the color
@@ -1010,9 +1006,6 @@ in ta_add_color_resets().
 
 Like ta_highlight(), but highlight all occurences instead of only the first.
 
-Performance: ~ 4k/s on my Core i5-2400 3.1GHz desktop for a ~ 1KB of text and a
-needle of length ~ 7 and number of occurences ~ 13.
-
 =head1 FAQ
 
 =head2 How do I truncate string based on number of characters?
@@ -1065,4 +1058,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
